@@ -1,6 +1,7 @@
 import argparse
 
 from mohou.default import create_default_encoding_rule
+from mohou.file import get_project_path
 from mohou.model import LSTMConfig
 from mohou.script_utils import create_default_logger, train_chimera
 from mohou.setting import setting
@@ -18,18 +19,18 @@ if __name__ == "__main__":
     )
     args = parser.parse_args()
 
-    args = parser.parse_args()
+    project_name: str = args.pn
+    n_epoch: int = args.n
+    n_aug: int = args.aug
+    n_hidden: int = args.hidden
+    n_layer: int = args.layer
+    valid_ratio: float = args.valid_ratio
 
-    project_name = args.pn
-    n_epoch = args.n
-    n_aug = args.aug
-    n_hidden = args.hidden
-    n_layer = args.layer
-    valid_ratio = args.valid_ratio
+    project_path = get_project_path(project_name)
 
-    logger = create_default_logger(project_name, "chimera")  # noqa
-    encoding_rule = create_default_encoding_rule(project_name)
+    logger = create_default_logger(project_path, "chimera")  # noqa
+    encoding_rule = create_default_encoding_rule(project_path)
     lstm_config = LSTMConfig(encoding_rule.dimension, n_hidden=n_hidden, n_layer=n_layer)
     train_config = TrainConfig(n_epoch=n_epoch, batch_size=30, valid_data_ratio=valid_ratio)
 
-    train_chimera(project_name, encoding_rule, lstm_config, train_config)
+    train_chimera(project_path, encoding_rule, lstm_config, train_config)
